
'''
Based on https://www.tensorflow.org/beta/guide/keras/saving_and_serializing

    Inference using a sequential or functional model created using tensorflow 2.0.
    This example is using the MNIST database of handwritten digits
    (http://yann.lecun.com/exdb/mnist/)
    Author: tensorflow
    Project: https://github.com/tensorflow/docs
    Modifications:

*****************************************************************
Licensed Materials - Property of IBM
(C) Copyright IBM Corp. 2019. All Rights Reserved.
US Government Users Restricted Rights - Use, duplication or
disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
*****************************************************************
'''
import argparse

import tensorflow as tf
import numpy as np

from tensorflow import keras

def main():
    (x_train, y_train), (x_test, y_test) = keras.datasets.mnist.load_data()
    x_test = x_test.reshape(10000, 784).astype('float32') / 255

    new_model = keras.models.load_model(FLAGS.saved_model_path)

    new_preds = new_model.predict(x_test)
    new_preds = np.array(tf.argmax(new_preds, 1))
    print ("Prediction Accuracy:", np.sum(new_preds == y_test) / y_test.shape[0])


if __name__ == '__main__':
    parser = argparse.ArgumentParser()
    parser.add_argument('--saved_model_path', type=str, default="/tmp/mnist-model/mnist-seq-training.h5")

    FLAGS, unparsed = parser.parse_known_args()

    main()
