'''
Based on https://www.tensorflow.org/beta/guide/keras/saving_and_serializing

    A custom model created using tensorflow 2.0.
    This example is using the MNIST database of handwritten digits
    (http://yann.lecun.com/exdb/mnist/)
    Author: tensorflow
    Project: https://github.com/tensorflow/docs
    Modifications:

*****************************************************************
Licensed Materials - Property of IBM
(C) Copyright IBM Corp. 2019. All Rights Reserved.
US Government Users Restricted Rights - Use, duplication or
disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
*****************************************************************
'''


import tensorflow as tf

class ThreeLayerMLP(tf.keras.Model):

  def __init__(self, name=None):
    super(ThreeLayerMLP, self).__init__(name=name)
    self.dense_1    = tf.keras.layers.Dense(64, activation='relu', name='dense_1')
    self.dense_2    = tf.keras.layers.Dense(64, activation='relu', name='dense_2')
    self.pred_layer = tf.keras.layers.Dense(10, activation='softmax', name='predictions')

  def call(self, inputs):
    x = self.dense_1(inputs)
    x = self.dense_2(x)
    return self.pred_layer(x)

def get_model():
  return ThreeLayerMLP(name='3_layer_mlp')


