"""
*****************************************************************
Licensed Materials - Property of IBM
(C) Copyright IBM Corp. 2019. All Rights Reserved.
US Government Users Restricted Rights - Use, duplication or
disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
*****************************************************************
"""

import tensorflow as tf
import ddl
import numpy as np
import sys
from os import environ
import argparse


def variable_bcast_test (data, test_name):
    print ("DDL_RANK={} Running test for {}".format(ddl_rank, test_name))
    x = tf.Variable(data, name="x")
    y = tf.Variable(data + 1, name="y")

    print ("Before bcast op: DDL_RANK:{}, x={}, y={}".format(ddl_rank, x.numpy(), y.numpy()))
    (x, y) = ddl.get_global_variable_bcast_op([x, y])
    print ("After bcast op: DDL_RANK:{}, x={}, y={}".format(ddl_rank, x.numpy(), y.numpy()))

    if np.all(x.numpy() != 0) or np.all(y.numpy() != 1):
        print ("get_global_variable_bcast_op failed to send rank 0's " \
               "variable values to other ranks")
        sys.exit(1)


if __name__ == '__main__':
    parser = argparse.ArgumentParser(
        description='DDL global variable bcast op test')
    parser.add_argument('--ddl_options', type=str,
                        default='-mode b:2x1 -dump_iter 100',
                        help='DDL options. e.g. "-mode b:2x1 -dump_iter 100"')
    FLAGS, unparsed = parser.parse_known_args()

    if environ.get('DDL_OPTIONS') is None:
        #Need to explicitly call ddl.init
        ddl.init(FLAGS.ddl_options)

    ddl_rank = ddl.rank()
    variable_bcast_test(ddl_rank, "Scalar int")

    float16_arr = np.ones((4,4), dtype=np.float16) * ddl_rank
    variable_bcast_test(float16_arr, "4x4 array of float16")

    float32_arr = np.ones((4,4), dtype=np.float32) * ddl_rank
    variable_bcast_test(float32_arr, "4x4 array of float32")
